import { s as shared } from './generated-shared.js';

var main2 = shared.map(d => d + 2);

export { main2 as default };
